@@ -1,6 +1,6 @@
-from narada.client import Narada
-from narada.config import BrowserConfig
-from narada.errors import (
+import importlib.metadata
+
+from narada_core.errors import (
     NaradaError,
     NaradaExtensionMissingError,
     NaradaExtensionUnauthenticatedError,
@@ -8,18 +8,25 @@ from narada.errors import (
     NaradaTimeoutError,
     NaradaUnsupportedBrowserError,
 )
-from narada.window import (
-    BrowserWindow,
-    Response,
-    ResponseContent,
-)
+from narada_core.models import Agent, File, Response, ResponseContent
 
-__version__ = "0.1.6"
+from narada.client import Narada
+from narada.config import BrowserConfig
+from narada.window import LocalBrowserWindow, RemoteBrowserWindow
 
+# Get version from package metadata
+try:
+    __version__ = importlib.metadata.version("narada")
+except Exception:
+    # Fallback version if package metadata is not available
+    __version__ = "unknown"
 
 __all__ = [
+    "__version__",
+    "Agent",
     "BrowserConfig",
-    "BrowserWindow",
+    "File",
+    "LocalBrowserWindow",
     "Narada",
     "NaradaError",
     "NaradaExtensionMissingError",
@@ -27,6 +34,7 @@ __all__ = [
     "NaradaInitializationError",
     "NaradaTimeoutError",
     "NaradaUnsupportedBrowserError",
+    "RemoteBrowserWindow",
     "Response",
     "ResponseContent",
 ]
